@@ -1,6 +1,5 @@
 /* Message catalogs for internationalization.
-   Copyright (C) 1995-1997, 2000-2015 Free Software Foundation,
-   Inc.
+   Copyright (C) 1995-1997, 2000-2016, 2018-2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -13,7 +12,7 @@
    GNU Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifndef _LIBINTL_H
 #define _LIBINTL_H 1
@@ -55,7 +54,7 @@ extern "C" {
 
 
 /* Version number: (major<<16) + (minor<<8) + subminor */
-#define LIBINTL_VERSION 0x001307
+#define LIBINTL_VERSION 0x001603
 extern int libintl_version;
 
 
@@ -112,7 +111,7 @@ extern int libintl_version;
 /* _INTL_MAY_RETURN_STRING_ARG(n) declares that the given function may return
    its n-th argument literally.  This enables GCC to warn for example about
    printf (gettext ("foo %y")).  */
-#if defined __GNUC__ && __GNUC__ >= 3 && !(defined __APPLE_CC__ && __APPLE_CC__ > 1 && defined __cplusplus)
+#if defined __GNUC__ && __GNUC__ >= 3 && !(defined __APPLE_CC__ && __APPLE_CC__ > 1 && !(defined __clang__ && __clang__ && __clang_major__ >= 3) && defined __cplusplus)
 # define _INTL_MAY_RETURN_STRING_ARG(n) __attribute__ ((__format_arg__ (n)))
 #else
 # define _INTL_MAY_RETURN_STRING_ARG(n)
@@ -124,14 +123,16 @@ extern int libintl_version;
 #ifdef _INTL_REDIRECT_INLINE
 extern char *libintl_gettext (const char *__msgid)
        _INTL_MAY_RETURN_STRING_ARG (1);
-static inline char *gettext (const char *__msgid)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (1)
+char *gettext (const char *__msgid)
 {
   return libintl_gettext (__msgid);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define gettext libintl_gettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define gettext libintl_gettext
+# endif
 extern char *gettext (const char *__msgid)
        _INTL_ASM (libintl_gettext)
        _INTL_MAY_RETURN_STRING_ARG (1);
@@ -142,14 +143,16 @@ extern char *gettext (const char *__msgid)
 #ifdef _INTL_REDIRECT_INLINE
 extern char *libintl_dgettext (const char *__domainname, const char *__msgid)
        _INTL_MAY_RETURN_STRING_ARG (2);
-static inline char *dgettext (const char *__domainname, const char *__msgid)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (2)
+char *dgettext (const char *__domainname, const char *__msgid)
 {
   return libintl_dgettext (__domainname, __msgid);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define dgettext libintl_dgettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define dgettext libintl_dgettext
+# endif
 extern char *dgettext (const char *__domainname, const char *__msgid)
        _INTL_ASM (libintl_dgettext)
        _INTL_MAY_RETURN_STRING_ARG (2);
@@ -161,15 +164,16 @@ extern char *dgettext (const char *__domainname, const char *__msgid)
 extern char *libintl_dcgettext (const char *__domainname, const char *__msgid,
                                 int __category)
        _INTL_MAY_RETURN_STRING_ARG (2);
-static inline char *dcgettext (const char *__domainname, const char *__msgid,
-                               int __category)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (2)
+char *dcgettext (const char *__domainname, const char *__msgid, int __category)
 {
   return libintl_dcgettext (__domainname, __msgid, __category);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define dcgettext libintl_dcgettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define dcgettext libintl_dcgettext
+# endif
 extern char *dcgettext (const char *__domainname, const char *__msgid,
                         int __category)
        _INTL_ASM (libintl_dcgettext)
@@ -183,15 +187,17 @@ extern char *dcgettext (const char *__domainname, const char *__msgid,
 extern char *libintl_ngettext (const char *__msgid1, const char *__msgid2,
                                unsigned long int __n)
        _INTL_MAY_RETURN_STRING_ARG (1) _INTL_MAY_RETURN_STRING_ARG (2);
-static inline char *ngettext (const char *__msgid1, const char *__msgid2,
-                              unsigned long int __n)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (1) _INTL_MAY_RETURN_STRING_ARG (2)
+char *ngettext (const char *__msgid1, const char *__msgid2,
+                unsigned long int __n)
 {
   return libintl_ngettext (__msgid1, __msgid2, __n);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define ngettext libintl_ngettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define ngettext libintl_ngettext
+# endif
 extern char *ngettext (const char *__msgid1, const char *__msgid2,
                        unsigned long int __n)
        _INTL_ASM (libintl_ngettext)
@@ -204,15 +210,17 @@ extern char *ngettext (const char *__msgid1, const char *__msgid2,
 extern char *libintl_dngettext (const char *__domainname, const char *__msgid1,
                                 const char *__msgid2, unsigned long int __n)
        _INTL_MAY_RETURN_STRING_ARG (2) _INTL_MAY_RETURN_STRING_ARG (3);
-static inline char *dngettext (const char *__domainname, const char *__msgid1,
-                               const char *__msgid2, unsigned long int __n)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (2) _INTL_MAY_RETURN_STRING_ARG (3)
+char *dngettext (const char *__domainname, const char *__msgid1,
+                 const char *__msgid2, unsigned long int __n)
 {
   return libintl_dngettext (__domainname, __msgid1, __msgid2, __n);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define dngettext libintl_dngettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define dngettext libintl_dngettext
+# endif
 extern char *dngettext (const char *__domainname,
                         const char *__msgid1, const char *__msgid2,
                         unsigned long int __n)
@@ -227,16 +235,18 @@ extern char *libintl_dcngettext (const char *__domainname,
                                  const char *__msgid1, const char *__msgid2,
                                  unsigned long int __n, int __category)
        _INTL_MAY_RETURN_STRING_ARG (2) _INTL_MAY_RETURN_STRING_ARG (3);
-static inline char *dcngettext (const char *__domainname,
-                                const char *__msgid1, const char *__msgid2,
-                                unsigned long int __n, int __category)
+static inline
+_INTL_MAY_RETURN_STRING_ARG (2) _INTL_MAY_RETURN_STRING_ARG (3)
+char *dcngettext (const char *__domainname,
+                  const char *__msgid1, const char *__msgid2,
+                  unsigned long int __n, int __category)
 {
   return libintl_dcngettext (__domainname, __msgid1, __msgid2, __n, __category);
 }
 #else
-#ifdef _INTL_REDIRECT_MACROS
-# define dcngettext libintl_dcngettext
-#endif
+# ifdef _INTL_REDIRECT_MACROS
+#  define dcngettext libintl_dcngettext
+# endif
 extern char *dcngettext (const char *__domainname,
                          const char *__msgid1, const char *__msgid2,
                          unsigned long int __n, int __category)
@@ -249,23 +259,23 @@ extern char *dcngettext (const char *__domainname,
 /* Set the current default message catalog to DOMAINNAME.
    If DOMAINNAME is null, return the current default.
    If DOMAINNAME is "", reset to the default of "messages".  */
-#ifdef _INTL_REDIRECT_INLINE
+# ifdef _INTL_REDIRECT_INLINE
 extern char *libintl_textdomain (const char *__domainname);
 static inline char *textdomain (const char *__domainname)
 {
   return libintl_textdomain (__domainname);
 }
-#else
-#ifdef _INTL_REDIRECT_MACROS
-# define textdomain libintl_textdomain
-#endif
+# else
+#  ifdef _INTL_REDIRECT_MACROS
+#   define textdomain libintl_textdomain
+#  endif
 extern char *textdomain (const char *__domainname)
        _INTL_ASM (libintl_textdomain);
-#endif
+# endif
 
 /* Specify that the DOMAINNAME message catalog will be found
    in DIRNAME rather than in the system locale data base.  */
-#ifdef _INTL_REDIRECT_INLINE
+# ifdef _INTL_REDIRECT_INLINE
 extern char *libintl_bindtextdomain (const char *__domainname,
                                      const char *__dirname);
 static inline char *bindtextdomain (const char *__domainname,
@@ -273,17 +283,38 @@ static inline char *bindtextdomain (const char *__domainname,
 {
   return libintl_bindtextdomain (__domainname, __dirname);
 }
-#else
-#ifdef _INTL_REDIRECT_MACROS
-# define bindtextdomain libintl_bindtextdomain
-#endif
+# else
+#  ifdef _INTL_REDIRECT_MACROS
+#   define bindtextdomain libintl_bindtextdomain
+#  endif
 extern char *bindtextdomain (const char *__domainname, const char *__dirname)
        _INTL_ASM (libintl_bindtextdomain);
-#endif
+# endif
+
+# if defined _WIN32 && !defined __CYGWIN__
+/* Specify that the DOMAINNAME message catalog will be found
+   in WDIRNAME rather than in the system locale data base.  */
+#  ifdef _INTL_REDIRECT_INLINE
+extern wchar_t *libintl_wbindtextdomain (const char *__domainname,
+                                         const wchar_t *__wdirname);
+static inline wchar_t *wbindtextdomain (const char *__domainname,
+                                        const wchar_t *__wdirname)
+{
+  return libintl_wbindtextdomain (__domainname, __wdirname);
+}
+#  else
+#   ifdef _INTL_REDIRECT_MACROS
+#    define wbindtextdomain libintl_wbindtextdomain
+#   endif
+extern wchar_t *wbindtextdomain (const char *__domainname,
+                                 const wchar_t *__wdirname)
+       _INTL_ASM (libintl_wbindtextdomain);
+#  endif
+# endif
 
 /* Specify the character encoding in which the messages from the
    DOMAINNAME message catalog will be returned.  */
-#ifdef _INTL_REDIRECT_INLINE
+# ifdef _INTL_REDIRECT_INLINE
 extern char *libintl_bind_textdomain_codeset (const char *__domainname,
                                               const char *__codeset);
 static inline char *bind_textdomain_codeset (const char *__domainname,
@@ -291,14 +322,14 @@ static inline char *bind_textdomain_codeset (const char *__domainname,
 {
   return libintl_bind_textdomain_codeset (__domainname, __codeset);
 }
-#else
-#ifdef _INTL_REDIRECT_MACROS
-# define bind_textdomain_codeset libintl_bind_textdomain_codeset
-#endif
+# else
+#  ifdef _INTL_REDIRECT_MACROS
+#   define bind_textdomain_codeset libintl_bind_textdomain_codeset
+#  endif
 extern char *bind_textdomain_codeset (const char *__domainname,
                                       const char *__codeset)
        _INTL_ASM (libintl_bind_textdomain_codeset);
-#endif
+# endif
 
 
 
@@ -310,32 +341,49 @@ extern char *bind_textdomain_codeset (const char *__domainname,
    or gettext() but for which the format string could be the return value
    of _() or gettext() need to add this #include.  Oh well.  */
 
+/* Note: In C++ mode, it is not sufficient to redefine a symbol at the
+   preprocessor macro level, such as
+     #define sprintf libintl_sprintf
+   Some programs may reference std::sprintf after including <libintl.h>.
+   Therefore we must make sure that std::libintl_sprintf is defined and
+   identical to ::libintl_sprintf.
+   The user can define _INTL_CXX_NO_CLOBBER_STD_NAMESPACE to avoid this.
+   In such cases, they will not benefit from the overrides when using
+   the 'std' namespace, and they will need to do the references to the
+   'std' namespace *before* including <libintl.h> or "gettext.h".  */
+
 #if !1
 
-#include <stdio.h>
-#include <stddef.h>
+# include <stdio.h>
+# include <stddef.h>
 
 /* Get va_list.  */
-#if (defined __STDC__ && __STDC__) || defined __cplusplus || defined _MSC_VER
-# include <stdarg.h>
-#else
-# include <varargs.h>
-#endif
+# if (defined __STDC__ && __STDC__) || defined __cplusplus || defined _MSC_VER
+#  include <stdarg.h>
+# else
+#  include <varargs.h>
+# endif
 
-#if !(defined fprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef fprintf
-#define fprintf libintl_fprintf
+# if !((defined fprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_fprintf) /* don't override gnulib */
+#  undef fprintf
+#  define fprintf libintl_fprintf
 extern int fprintf (FILE *, const char *, ...);
-#endif
-#if !(defined vfprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef vfprintf
-#define vfprintf libintl_vfprintf
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_fprintf; }
+#  endif
+# endif
+# if !((defined vfprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_vfprintf) /* don't override gnulib */
+#  undef vfprintf
+#  define vfprintf libintl_vfprintf
 extern int vfprintf (FILE *, const char *, va_list);
-#endif
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vfprintf; }
+#  endif
+# endif
 
-#if !(defined printf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef printf
-#if defined __NetBSD__ || defined __BEOS__ || defined __CYGWIN__ || defined __MINGW32__
+# if !((defined printf && defined _GL_STDIO_H) || defined GNULIB_overrides_printf) /* don't override gnulib */
+#  undef printf
+#  if defined __NetBSD__ || defined __BEOS__ || defined __CYGWIN__ || defined __MINGW32__
 /* Don't break __attribute__((format(printf,M,N))).
    This redefinition is only possible because the libc in NetBSD, Cygwin,
    mingw does not have a function __printf__.
@@ -345,102 +393,186 @@ extern int vfprintf (FILE *, const char *, va_list);
               __asm__ (#__USER_LABEL_PREFIX__ "libintl_printf");
    But doing it now would introduce a binary incompatibility with already
    distributed versions of libintl on these systems.  */
-# define libintl_printf __printf__
-#endif
-#define printf libintl_printf
+#   define libintl_printf __printf__
+#  endif
+#  define printf libintl_printf
 extern int printf (const char *, ...);
-#endif
-#if !(defined vprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef vprintf
-#define vprintf libintl_vprintf
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_printf; }
+#  endif
+# endif
+# if !((defined vprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_vprintf) /* don't override gnulib */
+#  undef vprintf
+#  define vprintf libintl_vprintf
 extern int vprintf (const char *, va_list);
-#endif
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vprintf; }
+#  endif
+# endif
 
-#if !(defined sprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef sprintf
-#define sprintf libintl_sprintf
+# if !((defined sprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_sprintf) /* don't override gnulib */
+#  undef sprintf
+#  define sprintf libintl_sprintf
 extern int sprintf (char *, const char *, ...);
-#endif
-#if !(defined vsprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef vsprintf
-#define vsprintf libintl_vsprintf
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_sprintf; }
+#  endif
+# endif
+# if !((defined vsprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_vsprintf) /* don't override gnulib */
+#  undef vsprintf
+#  define vsprintf libintl_vsprintf
 extern int vsprintf (char *, const char *, va_list);
-#endif
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vsprintf; }
+#  endif
+# endif
 
-#if 1
+# if 1
 
-#if !(defined snprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef snprintf
-#define snprintf libintl_snprintf
+#  if !((defined snprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_snprintf) /* don't override gnulib */
+#   undef snprintf
+#   define snprintf libintl_snprintf
 extern int snprintf (char *, size_t, const char *, ...);
-#endif
-#if !(defined vsnprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef vsnprintf
-#define vsnprintf libintl_vsnprintf
+#   if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_snprintf; }
+#   endif
+#  endif
+#  if !((defined vsnprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_vsnprintf) /* don't override gnulib */
+#   undef vsnprintf
+#   define vsnprintf libintl_vsnprintf
 extern int vsnprintf (char *, size_t, const char *, va_list);
-#endif
+#   if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vsnprintf; }
+#   endif
+#  endif
 
-#endif
+# endif
 
-#if 1
+# if 1
 
-#if !(defined asprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef asprintf
-#define asprintf libintl_asprintf
+#  if !((defined asprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_asprintf) /* don't override gnulib */
+#   undef asprintf
+#   define asprintf libintl_asprintf
 extern int asprintf (char **, const char *, ...);
-#endif
-#if !(defined vasprintf && defined _GL_STDIO_H) /* don't override gnulib */
-#undef vasprintf
-#define vasprintf libintl_vasprintf
+#   if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_asprintf; }
+#   endif
+#  endif
+#  if !((defined vasprintf && defined _GL_STDIO_H) || defined GNULIB_overrides_vasprintf) /* don't override gnulib */
+#   undef vasprintf
+#   define vasprintf libintl_vasprintf
 extern int vasprintf (char **, const char *, va_list);
-#endif
+#   if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vasprintf; }
+#   endif
+#  endif
+
+# endif
+
+# if 1
+
+#  undef fwprintf
+#  define fwprintf libintl_fwprintf
+extern int fwprintf (FILE *, const wchar_t *, ...);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_fwprintf; }
+#  endif
+#  undef vfwprintf
+#  define vfwprintf libintl_vfwprintf
+extern int vfwprintf (FILE *, const wchar_t *, va_list);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vfwprintf; }
+#  endif
+
+#  undef wprintf
+#  define wprintf libintl_wprintf
+extern int wprintf (const wchar_t *, ...);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_wprintf; }
+#  endif
+#  undef vwprintf
+#  define vwprintf libintl_vwprintf
+extern int vwprintf (const wchar_t *, va_list);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vwprintf; }
+#  endif
+
+#  undef swprintf
+#  define swprintf libintl_swprintf
+extern int swprintf (wchar_t *, size_t, const wchar_t *, ...);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_swprintf; }
+#  endif
+#  undef vswprintf
+#  define vswprintf libintl_vswprintf
+extern int vswprintf (wchar_t *, size_t, const wchar_t *, va_list);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_vswprintf; }
+#  endif
+
+# endif
 
 #endif
 
+
+/* Support for retrieving the name of a locale_t object.  */
 #if 0
 
-#undef fwprintf
-#define fwprintf libintl_fwprintf
-extern int fwprintf (FILE *, const wchar_t *, ...);
-#undef vfwprintf
-#define vfwprintf libintl_vfwprintf
-extern int vfwprintf (FILE *, const wchar_t *, va_list);
+# ifndef GNULIB_defined_newlocale /* don't override gnulib */
+#  undef newlocale
+#  define newlocale libintl_newlocale
+extern locale_t newlocale (int, const char *, locale_t);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_newlocale; }
+#  endif
+# endif
 
-#undef wprintf
-#define wprintf libintl_wprintf
-extern int wprintf (const wchar_t *, ...);
-#undef vwprintf
-#define vwprintf libintl_vwprintf
-extern int vwprintf (const wchar_t *, va_list);
+# ifndef GNULIB_defined_duplocale /* don't override gnulib */
+#  undef duplocale
+#  define duplocale libintl_duplocale
+extern locale_t duplocale (locale_t);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_duplocale; }
+#  endif
+# endif
 
-#undef swprintf
-#define swprintf libintl_swprintf
-extern int swprintf (wchar_t *, size_t, const wchar_t *, ...);
-#undef vswprintf
-#define vswprintf libintl_vswprintf
-extern int vswprintf (wchar_t *, size_t, const wchar_t *, va_list);
-
-#endif
+# ifndef GNULIB_defined_freelocale /* don't override gnulib */
+#  undef freelocale
+#  define freelocale libintl_freelocale
+extern void freelocale (locale_t);
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_freelocale; }
+#  endif
+# endif
 
 #endif
 
 
 /* Support for the locale chosen by the user.  */
-#if (defined __APPLE__ && defined __MACH__) || defined _WIN32 || defined __WIN32__ || defined __CYGWIN__
+#if (defined __APPLE__ && defined __MACH__) || defined _WIN32 || defined __CYGWIN__
 
-#ifndef GNULIB_defined_setlocale /* don't override gnulib */
-#undef setlocale
-#define setlocale libintl_setlocale
+# ifndef GNULIB_defined_setlocale /* don't override gnulib */
+#  undef setlocale
+#  define setlocale libintl_setlocale
 extern char *setlocale (int, const char *);
-#endif
+#  if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_setlocale; }
+#  endif
+# endif
 
-#if 1
+# if 1
 
-#undef newlocale
-#define newlocale libintl_newlocale
+#  undef newlocale
+#  define newlocale libintl_newlocale
+/* Declare newlocale() only if the system headers define the 'locale_t' type. */
+#  if !(defined __CYGWIN__ && !defined LC_ALL_MASK)
 extern locale_t newlocale (int, const char *, locale_t);
+#   if defined __cplusplus && !defined _INTL_CXX_NO_CLOBBER_STD_NAMESPACE
+namespace std { using ::libintl_newlocale; }
+#   endif
+#  endif
 
-#endif
+# endif
 
 #endif
 
